@@ -28,10 +28,10 @@ def GATK_variant_discovery(sample, GATK_variant_discovery_flag):
         DBSNP:
         ''' 
     
-    spawn_job(jobname = 'GATK_variant_discovery', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "31gb", script = "/GATK_variant_discovery.sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR,p.GATK_VERSION, p.GENOME, p.DBSNP])
-    job_status(jobname = 'GATK_variant_discovery', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + ".raw.vcf", FLAG_PATH = p.FLAG_PATH)
+    spawn_job(jobname = 'GATK_variant_discovery', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "30gb", script = "/GATK_variant_discovery_" + p.GATK_VERSION + ".sh", args_list = [p.BWA_RESULTS, sample, p.TEMP_DIR,p.GATK_VERSION, p.GENOME, p.DBSNP])
+    job_status(jobname = 'GATK_variant_discovery', resultspath = p.BWA_RESULTS, SAMPLE = sample,  outputfilename = sample + "/" +  sample + ".raw.vcf", FLAG_PATH = p.FLAG_PATH)
     return
 
 if __name__ == '__main__':
     GATK_variant_discovery(sample, GATK_variant_discovery_flag)
-    sys.exit(0)
\ No newline at end of file
+    sys.exit(0)
