@@ -21,16 +21,16 @@ def RNAseq_QC(sample, RNAseq_QC_flag):
         BAM_FILE_NAME:
         
         RSEQC_REF:
-        
-        RSEQC_VERSION:
-        
+              
         TEMP_DIR:
         
         PICARD_VERSION:
+        
+        R_VERSION:
         '''
 
-    spawn_job(jobname = 'RNAseq_QC', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "16gb", script = "/RNAseq_QC.sh", args_list = [p.STAR_RESULTS, p.QC_PATH, p.BAM_FILE_NAME, p.RSEQC_REF, p.RSEQC_VERSION, p.TEMP_DIR, sample, p.PICARD_VERSION])
-    job_status(jobname = 'RNAseq_QC', resultspath = p.QC_PATH, SAMPLE = sample, outputfilename = sample + "/insert_size.inner_distance_plot.pdf", FLAG_PATH = p.FLAG_PATH)
+    spawn_job(jobname = 'RNAseq_QC', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "4gb", script = "/RNAseq_QC.sh", args_list = [p.STAR_RESULTS, p.QC_PATH, p.BAM_FILE_NAME, p.RSEQC_REF, p.TEMP_DIR, sample, p.PICARD_VERSION, p.R_VERSION])
+    job_status(jobname = 'RNAseq_QC', resultspath = p.QC_PATH, SAMPLE = sample, outputfilename = sample + "/insertSizeHist.pdf", FLAG_PATH = p.FLAG_PATH)
     return
 if __name__ == '__main__':
     RNAseq_QC(sample, RNAseq_QC_flag)
