@@ -18,7 +18,7 @@ def fastq_length_filter_miRNA(sample, fastq_length_filter_miRNA_flag):
     '''
     sample1 = p.TRIMMED_DATA_PATH + "/" + sample + '_trimmed.fastq'
     script = p.WORKING_DIR + "/" + "fastq_length_filter.py"
-    spawn_job(jobname = 'fastq_length_filter_miRNA', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "16gb", script = "/run_py_script.sh", args_list = [script, sample1,p.TRIMMED_DATA_PATH])
+    spawn_job(jobname = 'fastq_length_filter_miRNA', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "15gb", script = "/run_py_script.sh", args_list = [script, sample1,p.TRIMMED_DATA_PATH])
     job_status(jobname = 'fastq_length_filter_miRNA', resultspath = p.TRIMMED_DATA_PATH, SAMPLE = sample, outputfilename = sample + ".fastq", FLAG_PATH = p.FLAG_PATH)
     return
 
