@@ -27,9 +27,13 @@ def intogen(sample, intogen_flag):
         WORKING_DIR:
         
         TEMP_DIR:
+        
+        SCHEDULER:
+        
+        SNPIR_RESULTS:
         '''
     #vcf_file = p.SNPIR_RESULTS + "/" +sample + "/final_variants.vcf"
-    spawn_job(jobname = 'intogen', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "32gb", script = "/intogen_drmaa.sh", args_list = [p.VCF_FILE, p.INTOGEN_OPTIONS, p.INTOGEN_RESULTS, p.INTOGEN_VERSION,  p.USERNAME, p.WORKING_DIR, p.TEMP_DIR, sample])
+    spawn_job(jobname = 'intogen', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "240:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "29gb", script = "/intogen_drmaa.sh", args_list = [p.VCF_FILE, p.INTOGEN_OPTIONS, p.INTOGEN_RESULTS, p.INTOGEN_VERSION,  p.USERNAME, p.WORKING_DIR, p.TEMP_DIR, sample, p.SCHEDULER, p.SNPIR_RESULTS])
     job_status(jobname = 'intogen', resultspath = p.INTOGEN_RESULTS, SAMPLE = sample, outputfilename = sample + "/variant_genes.tsv", FLAG_PATH = p.FLAG_PATH)
     return
 if __name__ == '__main__':
