@@ -30,8 +30,8 @@ def star_piRNA(sample, star_flag):
         
         STAR_VERSION:
         ''' 
-    spawn_job(jobname = 'star_piRNA', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, walltime = "120:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "32gb", script = "/star_drmaa_" + p.ENDS + ".sh", args_list = [sample, p.RAW_DATA_DIR, p.STAR_INDEX, p.STAR_OPTIONS, p.STAR_RESULTS, p.SAMTOOLS_VERSION, p.STAR_VERSION])
-    job_status(jobname = 'star_piRNA', resultspath = p.STAR_RESULTS, SAMPLE = sample, outputfilename = sample + "/Aligned.out.sam", FLAG_PATH = p.FLAG_PATH)
+    spawn_job(jobname = 'star_piRNA', SAMPLE = sample, LOG_PATH = p.LOG_PATH, RESULTS_EMAIL = p.RESULTS_EMAIL, SCHEDULER = p.SCHEDULER, walltime = "120:00:00", queue = p.QUEUE, nodes = 1, ppn = 8, memory = "29gb", script = "/star_drmaa_" + p.ENDS + ".sh", args_list = [sample, p.RAW_DATA_DIR, p.STAR_INDEX, p.STAR_OPTIONS, p.STAR_RESULTS, p.SAMTOOLS_VERSION, p.STAR_VERSION])
+    job_status(jobname = 'star_piRNA', resultspath = p.STAR_RESULTS, SAMPLE = sample, outputfilename = sample + "/SJ.out.tab", FLAG_PATH = p.FLAG_PATH)
     return
 
 if __name__ == '__main__':
