@@ -21,7 +21,7 @@ module load bwa/$4
 bwa mem $8 \
   $5 \
   $7/$6_1.fastq \
-  $7/$6_2.fastq
+  $7/$6_2.fastq \
   > $1/$6/$6.sam
 
 ######################## SAMTOOLS SORT AND INDEX #######################
