@@ -14,13 +14,17 @@ export TMPDIR=$7  #TEMP_DIR
 module load intogen/$4
 
 
-#$1 p.VCF_FILE, 2 p.INTOGEN_OPTIONS, 3p.INTOGEN_RESULTS, 4p.INTOGEN_VERSION, 5p.USERNAME, 6p.WORKING_DIR, 7p.TEMP_DIR, 8 sample
-
+#$1 p.VCF_FILE, 2 p.INTOGEN_OPTIONS, 3p.INTOGEN_RESULTS, 4p.INTOGEN_VERSION, 5p.USERNAME, 6p.WORKING_DIR, 7p.TEMP_DIR, 8 sample $9 SCHEDULER $10 SNPIR_RESULTS
 
+sched=$9
 #create config file
-$6/intogen_config.sh $3/$8 > $3/$8/intogen.conf
+if [ "$sched" = "SGE" ]; then
+	$6/intogen_config_AWS.sh $3/$8 > $3/$8/intogen.conf
+else
+	$6/intogen_config.sh $3/$8 > $3/$8/intogen.conf
+fi
 
-run analysis -p $8 $2 -C $3/$8/intogen.conf $1/$8/intogen_input.vcf
+run analysis -p $8 $2 -C $3/$8/intogen.conf ${10}/$8/$1
 
 unzip $3/$8/results/$5/default/projects/$8/results.zip -d $7
 
