@@ -15,6 +15,6 @@ require(pander)
 require(KEGGREST)
 require(knitcitations) # https://github.com/cboettig/knitcitations
 
-source(paste(config$R_SOURCE_PATH, 'src/core/functions.R', sep=''))
+source(paste(config$R_SOURCE_PATH, '/src/core/functions.R', sep=''))
 
 cite_options(tooltip=TRUE) # use bootstrap to create mouse over citations
\ No newline at end of file
