@@ -10,8 +10,10 @@ mkdir -p $4
 
 #Loads specified tophat version
 module load tophat/$6
+module load bowtie/$8
+module load samtools/$9
 
-#Runs Tophat with $1 = SAMPLE, $2=RAW_DATA_DIR, $3=REF_GENES, $4=RESULTS_PATH, $5=BOWTIE_INDEX, $6=TOPHAT_VERSION, $7=TOPHAT_OPTIONS
+#Runs Tophat with $1 = SAMPLE, $2=RAW_DATA_DIR, $3=REF_GENES, $4=RESULTS_PATH, $5=BOWTIE_INDEX, $6=TOPHAT_VERSION, $7=TOPHAT_OPTIONS $8 BOWTIE_VERSION, $9 SAMTOOLS_VERSION
 tophat $7 -G $3 -o $4/$1 $5 $2/$1_1.fastq $2/$1_2.fastq
 
 exit 0
